@@ -3,20 +3,27 @@ from ... import SCSIReadCommand
 from ..operation_code import OperationCode
 from ..control import Control, DEFAULT_CONTROL
 from infi.instruct import UBInt8, UBInt16, BitFields, BitPadding, BitField, BitFlag, Struct
-from infi.instruct import Padding, Field, ConstField
-from infi.instruct.errors import InstructError
+from infi.instruct import Field, ConstField
+from infi.instruct.buffer import Buffer, be_int_field, bytes_ref
+
 
 # spc4r30: 6.4.2 (page 261)
 class PeripheralDeviceData(Struct):
     _fields_ = [
         BitFields(
-            BitField("type", 5), # 0-4
-            BitField("qualifier", 3), # 5-7
+            BitField("type", 5),  # 0-4
+            BitField("qualifier", 3),  # 5-7
         )
     ]
 
+
+class PeripheralDeviceDataBuffer(Buffer):
+    type = be_int_field(where=bytes_ref[0].bits[0:5])    # 0-4
+    qualifier = be_int_field(where=bytes_ref[0].bits[5:8])  # 5-7
+
 from ..operation_code import CDB_OPCODE_INQUIRY
 
+
 # spc4r30: 6.4.1 (page 259)
 class InquiryCommand(CDB):
     _fields_ = [
